****************************
The sherpa.estmethods module
****************************

.. currentmodule:: sherpa.estmethods

.. automodule:: sherpa.estmethods

   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api

      EstMethod
      Confidence
      Covariance
      Projection
      EstNewMin   

Class Inheritance Diagram
=========================

.. inheritance-diagram:: EstMethod Confidence Covariance Projection EstNewMin
   :parts: 1
